<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Form\FormStateInterface;

/**
 * Class OriginContentTypeFields.
 *
 * Provides form create and edit migration content types.
 *
 * @package Drupal\migrate_wizard\Form
 *
 * @ingroup migrate_wizard
 */
class OriginContentTypeFields extends BaseFormFields {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $origin_bundle = NULL) {
    $this->originBundle = $origin_bundle;
    $this->originType = 'node';
    $origin_node_entity = $this->entityTypeManager->getStorage('origin_node')->load($this->originBundle);
    $this->currentConfig = $origin_node_entity->shared_configuration;
    $this->manageFormService->setCurrentConfig($origin_node_entity->shared_configuration);
    $this->fieldsOriginBundle = $this->manageFormService->getFieldsOriginBundle($origin_node_entity, $this->originType);
    $this->manageFormService->setFieldsOriginBundle($this->fieldsOriginBundle);
    $type_fields_checkboxes = [
      'preserve_nid' => 'Preserve nid',
      'import_users' => 'Import users',
      'import_path_alias' => 'Import path alias',
    ];
    $this->checkboxes = array_merge($this->checkboxes, $type_fields_checkboxes);
    $form['origin_type'] = [
      '#type' => 'hidden',
      '#value' => 'node',
    ];
    $form['origin_bundle'] = [
      '#type' => 'hidden',
      '#value' => $origin_node_entity->id_origin,
    ];
    $origin_database_value = $origin_node_entity->use_env ? getenv($origin_node_entity->database) : $origin_node_entity->database;
    $form['origin_database'] = [
      '#type' => 'hidden',
      '#value' => $origin_database_value,
    ];
    $this->langCodes['default_lang']['value'] = $this->mwManageDataService->getOriginDefaultLangcode();
    $config_translation = $this->mwManageDataService->getOriginLanguages($form['origin_type']['#value'], str_replace('_' . $origin_database_value, '', $origin_bundle));

    foreach ($config_translation['origin_languages'] as $language) {
      $this->langCodes[$language . '_lang'] = [
        'markup' => $language,
        'value' => $language,
      ];
    }

    return parent::buildForm($form, $form_state, $origin_node_entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'manage_origin_content_type_fields';
  }

  /**
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   */
  public function getTitle($type = NULL): \Drupal\Core\StringTranslation\TranslatableMarkup {
    return parent::getTitle('node');
  }

}
