<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'default_files' field type.
 *
 * @FieldType(
 *     id="default_files",
 * )
 */
class FieldTypeMWDefaultFiles extends FieldTypeMWBase {

  public static function getD7MigrationConfig(&$wildcard_yml_config, $array_config, $migration_group_name) {
    $mw_database = parent::getMWDatabase($array_config['mw_database']);
    $wildcard_yml_config['id'] = 'files_' . $array_config['mw_database'];
    $wildcard_yml_config['label'] = 'files_' . $array_config['mw_database'];
    $wildcard_yml_config['migration_group'] = $migration_group_name;
    $wildcard_yml_config['migration_tags'][0] = $migration_group_name;
    $wildcard_yml_config['source']['key'] = $mw_database->get('key');
    $database = $mw_database->get('use_env') ? getenv($mw_database->get('id')) : $mw_database->get('id');
    $wildcard_yml_config['source']['mw_database'] = $database;
    $wildcard_yml_config['source']['constants']['source_base_path'] = $mw_database->url_files_prod;

    if ($mw_database->shared_configuration['migration_files']['preserve_fid']) {
      $wildcard_yml_config['process']['fid'] = 'fid';
    }
  }

}
