<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'generic_date' field type.
 *
 * @FieldType(
 *     id="generic_date",
 * )
 */
class FieldTypeMWGenericDate extends FieldTypeMWBase {

  public static function getD7MigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $config, $entityFieldManager, $fieldTypeMWManager, $langcode = NULL): void {
    $array_config[$data_field['destiny']][] = [
      'plugin' => 'skip_on_empty',
      'source' => $origin_field,
      'method' => 'process',
    ];

    $from_format = 'Y-m-d\TH:i:s';
    $to_format = 'Y-m-d\TH:i:s';

    switch ($data_field['type'] . '.' . $data_field['destiny_type']) {
      case 'datestamp.timestamp':
        $from_format = 'U';
        $to_format = 'U';

        break;

      case 'datetime.datetime':
        $from_format = 'Y-m-d H:i:s';

        if (isset($data_field['format']) && $data_field['format'] !== NULL) {
          $to_format = $data_field['format'];
        }

        break;

      case 'datetime.yearonly':
        $from_format = 'Y-m-d H:i:s';
        $to_format = 'Y';

        break;
    }
    $array_config[$data_field['destiny']][] = [
      'plugin' => 'sub_process',
      'process' => [
        'value' => [
          'plugin' => 'format_date',
          'source' => 'value',
          'from_format' => $from_format,
          'to_format' => $to_format,
        ],
      ],
    ];
    $wildcard_yml_config['process'] = array_merge($wildcard_yml_config['process'], $array_config);
  }

}
