<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'generic_text_long' field type.
 *
 * @FieldType(
 *     id="generic_text_long",
 * )
 */
class FieldTypeMWGenericTextLong extends FieldTypeMWBase {

  public static function getD7MigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $shared_configuration, $entityFieldManager, $fieldTypeMWManager, $langcode = NULL): void {
    $origin_field_value = $origin_field;

    if ($origin_field === 'description' && $wildcard_yml_config['source']['origin_type'] === 'vocabulary' && $langcode !== NULL) {
      $origin_field_value = 'description_translated';
    }

    if ($wildcard_yml_config['source']['origin_type'] === 'taxonomy_term' && $wildcard_yml_config['destination']['plugin'] === 'entity:node' && $origin_field === 'description') {
      $array_config[$data_field['destiny'] . '/value'][] = [
        'plugin' => 'skip_on_empty',
        'source' => $origin_field_value,
        'method' => 'process',
      ];

      $array_config[$data_field['destiny'] . '/format'][] = [
        'plugin' => 'static_map',
        'source' => 'format',
        'map' => $shared_configuration['origin_formats'],
        'default_value' => 'full_html',
      ];
    }
    else {
      $array_config[$data_field['destiny']][] = [
        'plugin' => 'skip_on_empty',
        'source' => $origin_field_value,
        'method' => 'process',
      ];

      $array_config[$data_field['destiny']][] = [
        'plugin' => 'sub_process',
        'method' => 'process',
        'process' => [
          'value' => 'value',
          'summary' => 'summary',
          'format' => [
            'plugin' => 'static_map',
            'source' => 'format',
            'map' => $shared_configuration['origin_formats'],
            'default_value' => 'full_html',
          ],
        ],
      ];
    }

    $wildcard_yml_config['process'] = array_merge($wildcard_yml_config['process'], $array_config);
  }

}
