<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\migrate\process;

use Drupal\migrate\MigrateExecutableInterface;
use Drupal\migrate\ProcessPluginBase;
use Drupal\migrate\Row;

/**
 * Format range explode.
 *
 * @MigrateProcessPlugin(
 *     id="format_range_explode"
 * )
 */
class FormatRangeExplode extends ProcessPluginBase {

  /**
   * {@inheritdoc}
   */
  public function transform($value, MigrateExecutableInterface $migrate_executable, Row $row, $destination_property) {
    $values = explode('||', $value[0]);
    $values2 = explode('||', $value[1]);
    $new_value = [];

    foreach ($values as $key => $value) {
      $new_value[] = [
        'from' => $value,
        'to' => $values2[$key],
      ];
    }

    return $new_value;
  }

}
