<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\migrate\process;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\migrate\MigrateException;
use Drupal\migrate\MigrateExecutableInterface;
use Drupal\migrate\Plugin\MigrationInterface;
use Drupal\migrate\ProcessPluginBase;
use Drupal\migrate\Row;
use Drupal\migrate_wizard\Plugin\migrate\destination\MWEntityMedia;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Geofield explode.
 *
 * @MigrateProcessPlugin(
 *     id="mw_process_entity_media"
 * )
 */
class MWProcessEntityMedia extends ProcessPluginBase implements ContainerFactoryPluginInterface {

  /**
   * The entity storage.
   *
   * @var EntityStorageInterface
   */
  protected $entityMediaPlugin;

  public function __construct(array $configuration, $plugin_id, array $plugin_definition, MWEntityMedia $entity_media_plugin) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->entityMediaPlugin = $entity_media_plugin;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition, ?MigrationInterface $migration = NULL) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('plugin.manager.migrate.destination')->createInstance('mwentity:media', $configuration, $migration)
    );
  }

  /**
   * {@inheritdoc}
   */
  public function transform($value, MigrateExecutableInterface $migrate_executable, Row $row, $destination_property) {
    $destination = $row->getSourceProperty('uri');

    if (empty($destination)) {
      throw new MigrateException('Destination property uri not provided');
    }
    $entity = $this->entityMediaPlugin->getEntity($row, []);
    $entity->save();

    return $entity->id();
  }

}
